@@ -5,32 +5,42 @@
 #' This is exactly the same as default header_n execpt it works on the built
 #' pop_data.
 #'
+#' This function follows the Extract-Process-Bind pattern:
+#' 1. Extracts needed bindings from table environment
+#' 2. Processes data in function environment
+#' 3. Binds results back to table environment
+#'
 #' @noRd
 build_header_n <- function(table) {
-  evalq({
-
-    # Error out if the cols variables around found in the pop_data
-    assert_quo_var_present(cols, names(built_pop_data))
-
-    # If there is a distinct_by, use it to make the header_n
-    if(is.null(distinct_by)) {
-      df <- built_pop_data %>%
-        group_by(!!pop_treat_var, !!!cols) %>%
-        tally() %>%
-        ungroup() %>%
-        complete(!!pop_treat_var, !!!cols, fill = list(n = 0))
-    } else {
-      df <- built_pop_data %>%
-        distinct(!!!distinct_by, !!pop_treat_var, .keep_all = TRUE) %>%
-        group_by(!!pop_treat_var, !!!cols) %>%
-        tally() %>%
-        ungroup() %>%
-        complete(!!pop_treat_var, !!!cols, fill = list(n = 0))
-    }
-
-    header_n <- df
-    rm(df)
-  }, envir = table)
+  # EXTRACT: Get what we need from table environment
+  built_pop_data <- table$built_pop_data
+  pop_treat_var <- table$pop_treat_var
+  cols <- table$cols
+  distinct_by <- table$distinct_by
+  
+  # PROCESS: Calculate header N values in function environment
+  # Error out if the cols variables are not found in the pop_data
+  assert_quo_var_present(cols, names(built_pop_data))
+  
+  # If there is a distinct_by, use it to make the header_n
+  if(is.null(distinct_by)) {
+    header_n <- built_pop_data %>%
+      group_by(!!pop_treat_var, !!!cols) %>%
+      tally() %>%
+      ungroup() %>%
+      complete(!!pop_treat_var, !!!cols, fill = list(n = 0))
+  } else {
+    header_n <- built_pop_data %>%
+      distinct(!!!distinct_by, !!pop_treat_var, .keep_all = TRUE) %>%
+      group_by(!!pop_treat_var, !!!cols) %>%
+      tally() %>%
+      ungroup() %>%
+      complete(!!pop_treat_var, !!!cols, fill = list(n = 0))
+  }
+  
+  # BIND: Write results back to table environment
+  table$header_n <- header_n
+  
   table
 }
 
@@ -109,18 +119,15 @@ add_total_group <- function(table, group_name="Total") {
 
   assert_has_class(group_name, "character")
 
-  # Temporarily bind the group_name parameter to the table environment
-  env_bind(table, .tmp_name = group_name)
-
-  evalq({
-    # Create the function arguments and gather the list of all available treatment groups
-    treat_args <- list(current_env(), as.character(unlist(unique(pop_data[, quo_name(pop_treat_var)]))))
-    # Name the arguments
-    names(treat_args) <- c("table", .tmp_name)
-    # Call add_treat_grps with the derived arguments
-    do.call(add_treat_grps, treat_args)
-    # Remove the temporary variable
-    rm(.tmp_name, treat_args)
-  }, envir = table)
-  table
+  # EXTRACT: Get what we need from table environment
+  pop_data <- table$pop_data
+  pop_treat_var <- table$pop_treat_var
+  
+  # PROCESS: Create the function arguments and gather the list of all available treatment groups
+  treat_args <- list(table, as.character(unlist(unique(pop_data[, quo_name(pop_treat_var)]))))
+  # Name the arguments
+  names(treat_args) <- c("table", group_name)
+  
+  # Call add_treat_grps with the derived arguments
+  do.call(add_treat_grps, treat_args)
 }
