@@ -34,3 +34,18 @@ test_that("f_str objects are printed as expected", {
 
   expect_snapshot_output(str(t_$layers[[1]]$format_strings))
 })
+
+test_that("tplyr_table prints pop_data and pop_treat_var when set", {
+  load(test_path('adsl.Rdata'))
+
+  t_pop <- tplyr_table(mtcars, gear) %>%
+    set_pop_data(adsl) %>%
+    set_pop_treat_var(TRT01P) %>%
+    add_layer(
+      group_count(cyl)
+    )
+
+  out <- capture.output(print(t_pop))
+  expect_true(any(grepl("pop_data", out)))
+  expect_true(any(grepl("pop_treat_var", out)))
+})
